@@ -1,16 +1,17 @@
-from . import BaseApi, BaseUrl, Order, Region, Sort
+from . import TokenApi, SecretApi, Order, Region, Sort, LocalItem, WebItem
 from . import schemas
 
 
-class Auction(BaseApi):
-    def __init__(self, token: str, base_url: str | BaseUrl = "", item_id="", region=Region.RU):
-        super().__init__(token, base_url)
+class Auction:
+    def __init__(self, api: TokenApi | SecretApi, item_id: str | LocalItem | WebItem, region: Region, json: bool):
+        self._api = api
 
-        if not item_id:
-            raise ValueError(f"Invalid item '{item_id}'")
+        if isinstance(item_id, (LocalItem, WebItem)):
+            item_id = item_id.item_id
 
         self.item_id = item_id
         self.region = region
+        self.json = json
 
     def price_history(self, offset=0, limit=20, additional=False):
         """
@@ -22,11 +23,14 @@ class Auction(BaseApi):
             limit: Amount of prices to return, starting from offset, minimum 0, maximum 100, default 20
         """
 
-        self._offset_and_limit(offset, limit)
+        self._api._offset_and_limit(offset, limit)
 
         method = f"{self.region.value}/auction/{self.item_id}/history"
         payload = {"offset": offset, "limit": limit, "additional": additional}
-        response = self._request(method, payload)
+        response = self._api._request(method, payload)
+
+        if self.json is True:
+            return response
 
         return [
             schemas.Price(price)
@@ -45,11 +49,14 @@ class Auction(BaseApi):
             order: Either ASCENDING or DESCENDING
         """
 
-        self._offset_and_limit(offset, limit)
+        self._api._offset_and_limit(offset, limit)
 
         method = f"{self.region.value}/auction/{self.item_id}/lots"
         payload = {"offset": offset, "limit": limit, "sort": sort.value, "order": order.value, "additional": additional}
-        response = self._request(method, payload)
+        response = self._api._request(method, payload)
+
+        if self.json is True:
+            return response
 
         return [
             schemas.Lot(lots)
@@ -57,4 +64,4 @@ class Auction(BaseApi):
         ]
 
     def __repr__(self):
-        return f"{super().__repr__()} item_id='{self.item_id}' region='{self.region}'"
+        return f"<{self.__class__.__name__}> {self._api.__repr__()} item_id='{self.item_id}' region='{self.region}'"
